==> jc-1.4.0.tar.gz: java/awt/AWTPermission.h <==
// public final class java.awt.AWTPermission

// class file dependencies
// @dep_class 202a9eda3714f466 java_awt_AWTPermission
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_awt_AWTPermission_H_
#define _JC_java_awt_AWTPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AWTPermission$sub_refs	_jc_java_awt_AWTPermission$sub_refs;
typedef struct _jc_java_awt_AWTPermission$sub_nonrefs	_jc_java_awt_AWTPermission$sub_nonrefs;
typedef struct _jc_java_awt_AWTPermission$refs	_jc_java_awt_AWTPermission$refs;
typedef struct _jc_java_awt_AWTPermission$nonrefs	_jc_java_awt_AWTPermission$nonrefs;
typedef struct _jc_java_awt_AWTPermission$object	_jc_java_awt_AWTPermission$object;

typedef struct _jc_java_awt_AWTPermission$fields_struct	_jc_java_awt_AWTPermission$fields_struct;
typedef const struct _jc_java_awt_AWTPermission$vmethods	_jc_java_awt_AWTPermission$vmethods;
typedef const struct _jc_java_awt_AWTPermission$vtable	_jc_java_awt_AWTPermission$vtable;
typedef const struct _jc_java_awt_AWTPermission$vtype	_jc_java_awt_AWTPermission$vtype;

// Class fields structure
struct _jc_java_awt_AWTPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_AWTPermission$fields_struct _jc_java_awt_AWTPermission$class_fields;

// Constructors
extern void _jc_java_awt_AWTPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_AWTPermission$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_awt_AWTPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_awt_AWTPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_AWTPermission$vmethods {
};

// Vtable
struct _jc_java_awt_AWTPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_awt_AWTPermission$vmethods	java_awt_AWTPermission;
};

// Vtype
struct _jc_java_awt_AWTPermission$vtype {
	_jc_type			type;
	_jc_java_awt_AWTPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AWTPermission$refs {
    _jc_java_awt_AWTPermission$sub_refs	java_awt_AWTPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_awt_AWTPermission$sub_nonrefs	java_awt_AWTPermission;
};

// Object instance structure
struct _jc_java_awt_AWTPermission$object {
	_jc_java_awt_AWTPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTPermission$vtype	*vtype;
	_jc_java_awt_AWTPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTPermission$vtype _jc_java_awt_AWTPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTPermission$class_object;

#endif	/* _JC_java_awt_AWTPermission_H_ */

==> jc-1.4.6.tar.gz: java/awt/AWTPermission.h <==
// public final class java.awt.AWTPermission

// class file dependencies
// @dep_class 202a9eda3714f466 java_awt_AWTPermission
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d5158e4c9a3bab21 java_security_BasicPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_BasicPermission

#include "java/security/BasicPermission.h"

#ifndef _JC_java_awt_AWTPermission_H_
#define _JC_java_awt_AWTPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AWTPermission$sub_refs	_jc_java_awt_AWTPermission$sub_refs;
typedef struct _jc_java_awt_AWTPermission$sub_nonrefs	_jc_java_awt_AWTPermission$sub_nonrefs;
typedef struct _jc_java_awt_AWTPermission$refs	_jc_java_awt_AWTPermission$refs;
typedef struct _jc_java_awt_AWTPermission$nonrefs	_jc_java_awt_AWTPermission$nonrefs;
typedef struct _jc_java_awt_AWTPermission$object	_jc_java_awt_AWTPermission$object;

typedef struct _jc_java_awt_AWTPermission$fields_struct	_jc_java_awt_AWTPermission$fields_struct;
typedef const struct _jc_java_awt_AWTPermission$vmethods	_jc_java_awt_AWTPermission$vmethods;
typedef const struct _jc_java_awt_AWTPermission$vtable	_jc_java_awt_AWTPermission$vtable;
typedef const struct _jc_java_awt_AWTPermission$vtype	_jc_java_awt_AWTPermission$vtype;

// Class fields structure
struct _jc_java_awt_AWTPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_AWTPermission$fields_struct _jc_java_awt_AWTPermission$class_fields;

// Constructors
extern void _jc_java_awt_AWTPermission$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_AWTPermission$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_AWTPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_awt_AWTPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_AWTPermission$vmethods {
};

// Vtable
struct _jc_java_awt_AWTPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_security_BasicPermission$vmethods	java_security_BasicPermission;
	_jc_java_awt_AWTPermission$vmethods	java_awt_AWTPermission;
};

// Vtype
struct _jc_java_awt_AWTPermission$vtype {
	_jc_type			type;
	_jc_java_awt_AWTPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTPermission$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AWTPermission$refs {
    _jc_java_awt_AWTPermission$sub_refs	java_awt_AWTPermission;
    _jc_java_security_BasicPermission$sub_refs	java_security_BasicPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_security_BasicPermission$sub_nonrefs	java_security_BasicPermission;
    _jc_java_awt_AWTPermission$sub_nonrefs	java_awt_AWTPermission;
};

// Object instance structure
struct _jc_java_awt_AWTPermission$object {
	_jc_java_awt_AWTPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTPermission$vtype	*vtype;
	_jc_java_awt_AWTPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTPermission$vtype _jc_java_awt_AWTPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTPermission$class_object;

#endif	/* _JC_java_awt_AWTPermission_H_ */
